@@ -3,6 +3,6 @@ globalVariables(
         "text","start_num","num_char","median_value","last_flag","excess","value"
         ,"idx","x","y","los_group","los_index","los_ra_var","n","rar_index",
         "readmit_rate_bench","alos","record","total_records","prop_of_total",
-        ".cluster","centers","k_means","glance","tot.withinss"
+        ".cluster","centers","k_means","glance","tot.withinss","ump_lst"
     )
 )
